aboutsummaryrefslogtreecommitdiffstats
path: root/coin/provisioning/common
diff options
context:
space:
mode:
authorLiang Qi <liang.qi@qt.io>2017-11-16 23:14:25 +0100
committerLiang Qi <liang.qi@qt.io>2017-11-16 23:14:25 +0100
commit062b29b311cc87f438d7a6d5d5b5bfb8142fb7df (patch)
treeefd30f31dc86008734d902673309215377aedffe /coin/provisioning/common
parent26fda37639ce3c062eba550c9d87dc367b2b1c0c (diff)
parent329d718a1910f7b8e53b9d2feea2dc7a64b54adb (diff)
Merge remote-tracking branch 'origin/5.9' into 5.10
Diffstat (limited to 'coin/provisioning/common')
-rw-r--r--coin/provisioning/common/disable-ntp.ps12
-rwxr-xr-x[-rw-r--r--]coin/provisioning/common/fbx_linux.sh (renamed from coin/provisioning/common/install-java.ps1)46
-rwxr-xr-xcoin/provisioning/common/fbx_macos.sh79
-rw-r--r--coin/provisioning/common/fbx_windows.ps1 (renamed from coin/provisioning/common/01-macos-removethemall.sh)57
4 files changed, 142 insertions, 42 deletions
diff --git a/coin/provisioning/common/disable-ntp.ps1 b/coin/provisioning/common/disable-ntp.ps1
new file mode 100644
index 00000000..4ec9d1bd
--- /dev/null
+++ b/coin/provisioning/common/disable-ntp.ps1
@@ -0,0 +1,2 @@
+# Disable the NTP from syncing
+w32tm /config /syncfromflags:NO
diff --git a/coin/provisioning/common/install-java.ps1 b/coin/provisioning/common/fbx_linux.sh
index 50f12c89..66d4793b 100644..100755
--- a/coin/provisioning/common/install-java.ps1
+++ b/coin/provisioning/common/fbx_linux.sh
@@ -1,4 +1,6 @@
-############################################################################
+#!/bin/bash
+
+#############################################################################
##
## Copyright (C) 2017 The Qt Company Ltd.
## Contact: http://www.qt.io/licensing/
@@ -31,32 +33,30 @@
##
#############################################################################
-. "$PSScriptRoot\..\common\helpers.ps1"
+# This script installs FBX SDK
+source "${BASH_SOURCE%/*}/DownloadURL.sh"
+#s script installs FBX SDK
-# This script will install Java RE
-# Official Java RE 7 downloads require Oracle accounts. Using local mirrors only.
+set -e
+tarballName="fbx20161_2_fbxsdk_linux.tar.gz"
+targetFolder="/opt/fbx"
+cachedUrl="http://ci-files01-hki.intra.qt.io/input/fbx/$tarballName"
+officialUrl="http://download.autodesk.com/us/fbx_release_older/2016.1.2/$tarballName"
+sha1="b0a08778de025e2c6e90d6fbdb6531f74a3da605"
+tmpFolder="/tmp"
+targetFile="$tmpFolder/$tarballName"
+installer="$tmpFolder/fbx20161_2_fbxsdk_linux"
-$installdir = "C:\Program Files\Java\jre7"
+DownloadURL "$cachedUrl" "$officialUrl" "$sha1" "$targetFile"
-$version = "7u7"
-if( (is64bitWinHost) -eq 1 ) {
- $arch = "x64"
- $sha1 = "9af03460c416931bdee18c2dcebff5db50cb8cb3"
-}
-else {
- $arch = "i586"
- $sha1 = "f76b1be20b144b1ee1d1de3255edb0a6b57d0219"
-}
+sudo tar -C $tmpFolder -xf "$targetFile"
+sudo mkdir -p $targetFolder
+(echo "yes"; echo "n") | sudo "$installer" -w "$tmpFolder" "$targetFolder"
-$url_cache = "\\ci-files01-hki.intra.qt.io\provisioning\windows\jre-" + $version + "-windows-" + $arch + ".exe"
-$javaPackage = "C:\Windows\Temp\java-$version.exe"
+rm -rf "$targetFile"
-Copy-Item $url_cache $javaPackage
-cmd /c "$javaPackage /s SPONSORS=0"
-echo "Cleaning $javaPackage.."
-Remove-Item -Recurse -Force "$javaPackage"
+# Set env variables
+echo "export FBXSDK=$targetFolder" >> ~/.profile
-[Environment]::SetEnvironmentVariable("JAVA_HOME", "$installdir", [EnvironmentVariableTarget]::Machine)
-Add-Path "$installdir\bin"
+echo "FBX SDK = 2016.1.2" >> ~/versions.txt
-echo "Java = $version $arch" >> ~\versions.txt
diff --git a/coin/provisioning/common/fbx_macos.sh b/coin/provisioning/common/fbx_macos.sh
new file mode 100755
index 00000000..66a2d998
--- /dev/null
+++ b/coin/provisioning/common/fbx_macos.sh
@@ -0,0 +1,79 @@
+#!/bin/bash
+#############################################################################
+##
+## Copyright (C) 2017 The Qt Company Ltd.
+## Contact: http://www.qt.io/licensing/
+##
+## This file is part of the provisioning scripts of the Qt Toolkit.
+##
+## $QT_BEGIN_LICENSE:LGPL21$
+## Commercial License Usage
+## Licensees holding valid commercial Qt licenses may use this file in
+## accordance with the commercial license agreement provided with the
+## Software or, alternatively, in accordance with the terms contained in
+## a written agreement between you and The Qt Company. For licensing terms
+## and conditions see http://www.qt.io/terms-conditions. For further
+## information use the contact form at http://www.qt.io/contact-us.
+##
+## GNU Lesser General Public License Usage
+## Alternatively, this file may be used under the terms of the GNU Lesser
+## General Public License version 2.1 or version 3 as published by the Free
+## Software Foundation and appearing in the file LICENSE.LGPLv21 and
+## LICENSE.LGPLv3 included in the packaging of this file. Please review the
+## following information to ensure the GNU Lesser General Public License
+## requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+## http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+##
+## As a special exception, The Qt Company gives you certain additional
+## rights. These rights are described in The Qt Company LGPL Exception
+## version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+##
+## $QT_END_LICENSE$
+##
+#############################################################################
+
+# This script installs FBX SDK
+
+# shellcheck source=./try_catch.sh
+source "${BASH_SOURCE%/*}/try_catch.sh"
+
+fileName="fbx20161_2_fbxsdk_clang_mac.pkg.tgz"
+targetFolder="/opt/fbx"
+cachedUrl="/net/ci-files01-hki.intra.qt.io/hdd/www/input/fbx/$fileName"
+officialUrl="http://download.autodesk.com/us/fbx_release_older/2016.1.2/$fileName"
+sha1="f82535423c700c605320c52e13e781c92208ec6b"
+targetFolder="/tmp"
+targetFile="$targetFolder/$fileName"
+installer="$targetFolder/fbx20161_2_fbxsdk_clang_macos.pkg"
+
+ExceptionExtractPrimaryUrl=100
+
+try
+(
+ echo "Extracting '$cachedUrl'"
+ tar -xzf "$cachedUrl" -C "$targetFolder" || throw $ExceptionExtractPrimaryUrl
+)
+catch || {
+ case $ex_code in
+ $ExceptionExtractPrimaryUrl)
+ set -e
+ echo "Failed to uncompress from '$cachedUrl'"
+ echo "Downloading from '$officialUrl'"
+ curl --fail -L --retry 5 --retry-delay 5 -o "$targetFile" "$officialUrl" || exit 1;
+ echo "Checking SHA1 on PKG '$targetFile'"
+ echo "$sha1 *$targetFile" > $targetFile.sha1
+ shasum --check $targetFile.sha1
+ echo "Extracting '$targetFile'"
+ tar -xzf "$targetFile" -C "$targetFolder" || exit 1;
+ ;;
+ esac
+}
+set -e
+rm -rf "$targetFile"
+echo "Running installer for '$installer'"
+sudo installer -pkg "$installer" -target "/"
+
+# Set env variables
+echo "export FBXSDK=/Applications/Autodesk/FBX\ SDK/2016.1.2/" >> ~/.bashrc
+echo "FBX SDK = 2016.1.2" >> ~/versions.txt
+
diff --git a/coin/provisioning/common/01-macos-removethemall.sh b/coin/provisioning/common/fbx_windows.ps1
index f0e26480..00de579d 100644
--- a/coin/provisioning/common/01-macos-removethemall.sh
+++ b/coin/provisioning/common/fbx_windows.ps1
@@ -1,10 +1,9 @@
-#!/bin/sh
-#############################################################################
+############################################################################
##
-## Copyright (C) 2016 The Qt Company Ltd.
+## Copyright (C) 2017 The Qt Company Ltd.
## Contact: http://www.qt.io/licensing/
##
## This file is part of the test suite of the Qt Toolkit.
##
## $QT_BEGIN_LICENSE:LGPL21$
## Commercial License Usage
@@ -32,18 +31,38 @@
##
#############################################################################
-function RemoveDir {
- param=$1
-
- if [ ! -d $param ]
- then
- echo "'$param' don't exists"
- else
- echo "Removing $param..."
- sudo rm -fr $param
- fi
-}
-
-# Remove Android
-param="/opt/android"
-RemoveDir $param
+. "$PSScriptRoot\helpers.ps1"
+
+# This script will install FBX SDK
+
+$version = "2016.1.2"
+
+$name = "fbx20161_2_fbxsdk_vs2015_win"
+$packageName = "$name.7z"
+$installerName = "$name.exe"
+$cacheUrl = "\\ci-files01-hki.intra.qt.io\provisioning\fbx\$packageName"
+$sha1 = "3690400625672bef6369bcf90dcde4d78b493b24"
+
+# The executable is an interactive installer only. We can't run it in a script silently.
+# $officialUrl = "http://download.autodesk.com/us/fbx_release_older/2016.1.2/$installerName"
+# This sha is for the executable
+# $sha1 = "54f581c7c19cf5a08cf5e7bc62b8cc7f0617558e"
+
+#$targetFile = "C:\Windows\Temp\$packageName"
+$targetFolder = "C:\Program Files\"
+
+#echo "Downloading '$installerName'"
+#Download $officialUrl $cacheUrl $targetFile
+#Verify-Checksum $targetFile $sha1
+
+echo "Extracting '$cacheUrl'"
+#Extract-7Zip $cacheUrl $targetFolder
+Start-Process -FilePath "C:\Utils\sevenzip\7z.exe" -ArgumentList "x -y `"$cacheUrl`" -o`"$targetFolder`"" -Wait
+
+#Remove-Item -Recurse -Force "$packageName"
+
+echo "Adding environment variables."
+[Environment]::SetEnvironmentVariable("FBXSDK", "$targetFolder\Autodesk\FBX\FBX SDK\2016.1.2", [EnvironmentVariableTarget]::Machine)
+
+echo "FBX SDK = $version" >> ~\versions.txt
+
@@ -1,10 +1,9 @@
## Contact: http://www.qt.io/licensing/
##
-## This file is part of the test suite of the Qt Toolkit.
+## This file is part of the provisioning scripts of the Qt Toolkit.
##
## $QT_BEGIN_LICENSE:LGPL21$